EasyTV
=============================

Command Line Utility for search and download shows from EZTV

Setup
-----

`eazytv <https://pypi.org/project/eazytv/>`_ is available on PyPI.

Using pip:

::

    $ pip install eazytv

Usage
-----

::

    Usage: eazytv [OPTIONS] COMMAND [ARGS]...

    Options:
        --version   Show the version and exit.
        -h, --help  Show this message and exit.

    Commands:
        search    Search a show
        showlist  Display the showlist
